<?php

/**
 * Solid cover background layer
 *
 * PHP version 8
 *
 * Copyright (C) Villanova University 2018.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  Cover_Generator
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */

namespace VuFind\Cover\Layer;

/**
 * Solid cover background layer
 *
 * @category VuFind
 * @package  Cover_Generator
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development:plugins:hierarchy_components Wiki
 */
class SolidBackground extends AbstractBackgroundLayer
{
    /**
     * Render the layer
     *
     * @param resource $im       Image resource to draw on
     * @param array    $details  Cover details array (with title/author/call_number)
     * @param object   $settings Settings object
     *
     * @return void
     */
    public function render($im, $details, $settings)
    {
        // Fill solid color
        $seed = $this->createSeed($details['title'], $details['callnumber']);
        $accentColor = $this->getAccentColor($im, $seed, $settings);
        imagefilledrectangle(
            $im,
            0,
            0,
            $settings->width,
            $settings->height,
            $accentColor
        );
    }
}
